is_command_manual_section

Function is_command_manual_section 

pub fn is_command_manual_section(value: &str) -> bool
Return whether a manual section belongs to a command-page family.

Sections 1 and 8, including conventional extensions such as 1p, are eligible for a tldr command quick reference. Other manual categories describe APIs, formats, devices, games, or miscellaneous concepts.