pub fn render_search_text(search: &QuerySearch) -> StringExpand description
Render grep-like results with stable Markdown coordinates and node paths.
pub fn render_search_text(search: &QuerySearch) -> StringRender grep-like results with stable Markdown coordinates and node paths.