pub fn resolve_query(
request: &QueryRequest,
) -> Result<ResolvedContent, QueryError>Expand description
Query the local man database and optional offline tldr caches.
Errors
Returns QueryError for invalid input or when neither source can produce
readable content.