pub fn validate_search_query(request: &SearchQuery) -> Result<(), SearchError>Expand description
Validate search limits and compile its matcher without loading a manual.
Errors
Returns the same SearchError variants as search_query.
pub fn validate_search_query(request: &SearchQuery) -> Result<(), SearchError>Validate search limits and compile its matcher without loading a manual.
Returns the same SearchError variants as search_query.